# !/bin/bash
# Custom script to create SD Card image 
# WARNING: Experimental, not working with other targets

# [Internal] Source utilities scripts 
if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

# Create temporary workdir
WORKDIR=$(mktemp -d -t tmp-XXXXXXXXXX --tmpdir=${buildDir})
trap "rm -rf $WORKDIR" EXIT

# Source helper script to generate sdcard image
BUILDSTEP_SCRIPT_DIR=$(dirname $BUILDSTEP_SCRIPT_PATH)
source ${BUILDSTEP_SCRIPT_DIR}/sdcardBuilder.sh

do_buildstep_prepend

# Scale factor to get valid rootfs image size
# Note: The image size has to be bigger than the folder size, it ensure no error,
# 		The user can manually reduce image size afterward
: ${ROOTFS_SCALE_FACTOR:=1.3}

# Search tsv file 

if [ -z ${TSVFILE} ] ; then
	fatal "Missing tsv file; Please set the variable TSVFILE to the SD Card layout TSV file"
else
	LAYOUT=${TSVFILE}
fi

##########################
# Prepare boot partition #
##########################
# Get boot folder and format it with the right format and provide ${BOOTFS}
bootDir="${PROJECT_LOC}/output/boot"
cp -r ${bootDir} ${WORKDIR} 
workingBootDir="${WORKDIR}/boot"
bootPartName="bootPart"

install -d ${workingBootDir}/extlinux

# Generate_rootfs
#		Directory where the partition content is located
#		Partition format
#		Partition name (required for FAT)
#		Output Image name
#		Output Image size (optional)
#	imagesDir must be set to indicate output directory
imagesDir=${WORKDIR}
log_exec generate_rootfs "${workingBootDir}" "vfat" ${bootPartName} "BOOT"

BOOTFS="${WORKDIR}/${bootPartName}.vfat"
log "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ${BOOTFS} !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"

# Sometimes empty partitions are required ...
DO_NOT_POPULATE="${WORKDIR}/nop.ext4"
touch ${DO_NOT_POPULATE}

###################################
# Prepare rootfs partition        #
# ROOTFS var is defined in recipe #
###################################
if [ ! -f ${ROOTFS} ] ; then
	fatal 1 "Cannot retrieve the rootfs image: ${ROOTFS}; Please set the variable ROOTFS to the rootfs ext image"
fi  

##########################
# Generate SDCard image  #
##########################
log "==== Info ===="
log " bootfs ${BOOTFS}"
log " rootfs ${ROOTFS}"

do_create_sdcard_file ${LAYOUT} 

do_buildstep_append
