#!/bin/bash
# Script to install a the mali library in valid tree hierarchy

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

do_buildstep_prepend

MONOLITHIC_LIBMALI="libMali.so.9.0"
MALI_BACKEND_DEFAULT="x11"

#Identify the ARCH type

# The dummy build dependency to zlib allow to
# install the toolset before running this task
${CC} --version > ARCH_PLATFORM
if grep -q aarch64 "ARCH_PLATFORM"; then
	ARCH_PLATFORM_DIR=aarch64-linux-gnu
else
	ARCH_PLATFORM_DIR=arm-linux-gnueabihf
fi

log_exec rm -rf ${installDir}

# install headers
log_exec install -d -m 0655 ${D}${includedir}/EGL
log_exec install -m 0644 ${S}/${PV}/glesHeaders/EGL/*.h ${D}${includedir}/EGL/
log_exec install -d -m 0655 ${D}${includedir}/GLES
log_exec install -m 0644 ${S}/${PV}/glesHeaders/GLES/*.h ${D}${includedir}/GLES/
log_exec install -d -m 0655 ${D}${includedir}/GLES2
log_exec install -m 0644 ${S}/${PV}/glesHeaders/GLES2/*.h ${D}${includedir}/GLES2/
log_exec install -d -m 0655 ${D}${includedir}/KHR
log_exec install -m 0644 ${S}/${PV}/glesHeaders/KHR/*.h ${D}${includedir}/KHR/

log_exec install -d ${D}${libdir}/pkgconfig
log_exec install -m 0644 ${S}/egl.pc ${D}${libdir}/pkgconfig/egl.pc
log_exec install -m 0644 ${S}/glesv2.pc ${D}${libdir}/pkgconfig/glesv2.pc
log_exec install -m 0644 ${S}/glesv1.pc ${D}${libdir}/pkgconfig/glesv1.pc
log_exec install -m 0644 ${S}/glesv1_cm.pc ${D}${libdir}/pkgconfig/glesv1_cm.pc

log_exec install -d ${D}${libdir}
log_exec install -d ${D}${includedir}

log_exec cp -a --no-preserve=ownership ${S}/${PV}/${ARCH_PLATFORM_DIR}/common/*.so* ${D}${libdir}

log_exec install -Dm 0644 ${S}/${PV}/${ARCH_PLATFORM_DIR}/headless/${MONOLITHIC_LIBMALI} ${D}${libdir}/headless/${MONOLITHIC_LIBMALI}
log_exec ln -snf headless/${MONOLITHIC_LIBMALI} ${D}${libdir}/${MONOLITHIC_LIBMALI}

if [ "${USE_FB}" = "yes" ]; then
    log_exec install -Dm 0644 ${S}/${PV}/${ARCH_PLATFORM_DIR}/fbdev/${MONOLITHIC_LIBMALI} ${D}${libdir}/fbdev/${MONOLITHIC_LIBMALI}
    log_exec ln -snf fbdev/${MONOLITHIC_LIBMALI} ${D}${libdir}/${MONOLITHIC_LIBMALI}
fi
if [ "${USE_X11}" = "yes" ]; then
    log_exec install -Dm 0644 ${S}/${PV}/${ARCH_PLATFORM_DIR}/x11/${MONOLITHIC_LIBMALI} ${D}${libdir}/x11/${MONOLITHIC_LIBMALI}
    log_exec ln -snf x11/${MONOLITHIC_LIBMALI} ${D}${libdir}/${MONOLITHIC_LIBMALI}
else
    # We cant rely on the fact that all apps will use pkgconfig correctly
    sed -i -e 's/^#if defined(MESA_EGL_NO_X11_HEADERS)$/#if (1)/' ${D}${includedir}/EGL/eglplatform.h
fi
if [ "${USE_WL}" = "yes" ]; then
    log_exec install -m 0644 ${S}/${PV}/glesHeaders/GBM/gbm.h ${D}${includedir}/
    log_exec install -m 0644 ${S}/gbm.pc ${D}${libdir}/pkgconfig/gbm.pc
    log_exec install -Dm 0644 ${S}/${PV}/${ARCH_PLATFORM_DIR}/wayland/${MONOLITHIC_LIBMALI} ${D}${libdir}/wayland/${MONOLITHIC_LIBMALI}
	log_exec ln -snf wayland/${MONOLITHIC_LIBMALI} ${D}${libdir}/${MONOLITHIC_LIBMALI}
fi

do_buildstep_append